Parcellations
=============

.. automodule:: junifer.data.parcellations
   :members:

Coordinates
===========

.. automodule:: junifer.data.coordinates
   :members:


Masks
=====

.. automodule:: junifer.data.masks
   :members:
